SELinux: rename dentry_open to file_open
authorEric Paris <eparis@redhat.com>
Wed, 4 Apr 2012 17:45:40 +0000 (13:45 -0400)
committerElena Reshetova <elena.reshetova@intel.com>
Fri, 19 Oct 2012 10:27:13 +0000 (13:27 +0300)
dentry_open takes a file, rename it to file_open

Signed-off-by: Eric Paris <eparis@redhat.com>
Conflicts:

security/tomoyo/tomoyo.c

fs/open.c
include/linux/security.h
security/apparmor/lsm.c
security/capability.c
security/security.c
security/selinux/hooks.c
security/smack/smack_lsm.c
security/tomoyo/tomoyo.c

index b52cf01..67b9433 100644 (file)
--- a/fs/open.c
+++ b/fs/open.c
@@ -703,7 +703,7 @@ static struct file *__dentry_open(struct dentry *dentry, struct vfsmount *mnt,
 
        f->f_op = fops_get(inode->i_fop);
 
-       error = security_dentry_open(f, cred);
+       error = security_file_open(f, cred);
        if (error)
                goto cleanup_all;
 
index 8ce59ef..10eab8b 100644 (file)
@@ -630,10 +630,7 @@ static inline void security_free_mnt_opts(struct security_mnt_opts *opts)
  *     to receive an open file descriptor via socket IPC.
  *     @file contains the file structure being received.
  *     Return 0 if permission is granted.
- *
- * Security hook for dentry
- *
- * @dentry_open
+ * @file_open
  *     Save open-time permission checking state for later use upon
  *     file_permission, and recheck access if anything has changed
  *     since inode_permission.
@@ -1492,7 +1489,7 @@ struct security_operations {
        int (*file_send_sigiotask) (struct task_struct *tsk,
                                    struct fown_struct *fown, int sig);
        int (*file_receive) (struct file *file);
-       int (*dentry_open) (struct file *file, const struct cred *cred);
+       int (*file_open) (struct file *file, const struct cred *cred);
 
        int (*task_create) (unsigned long clone_flags);
        int (*cred_alloc_blank) (struct cred *cred, gfp_t gfp);
@@ -1751,7 +1748,7 @@ int security_file_set_fowner(struct file *file);
 int security_file_send_sigiotask(struct task_struct *tsk,
                                 struct fown_struct *fown, int sig);
 int security_file_receive(struct file *file);
-int security_dentry_open(struct file *file, const struct cred *cred);
+int security_file_open(struct file *file, const struct cred *cred);
 int security_task_create(unsigned long clone_flags);
 int security_cred_alloc_blank(struct cred *cred, gfp_t gfp);
 void security_cred_free(struct cred *cred);
@@ -2251,8 +2248,8 @@ static inline int security_file_receive(struct file *file)
        return 0;
 }
 
-static inline int security_dentry_open(struct file *file,
-                                      const struct cred *cred)
+static inline int security_file_open(struct file *file,
+                                    const struct cred *cred)
 {
        return 0;
 }
index 3783202..371c4b3 100644 (file)
@@ -374,7 +374,7 @@ static int apparmor_inode_getattr(struct vfsmount *mnt, struct dentry *dentry)
                                      AA_MAY_META_READ);
 }
 
-static int apparmor_dentry_open(struct file *file, const struct cred *cred)
+static int apparmor_file_open(struct file *file, const struct cred *cred)
 {
        struct aa_file_cxt *fcxt = file->f_security;
        struct aa_profile *profile;
@@ -639,9 +639,9 @@ static struct security_operations apparmor_ops = {
        .path_chmod =                   apparmor_path_chmod,
        .path_chown =                   apparmor_path_chown,
        .path_truncate =                apparmor_path_truncate,
-       .dentry_open =                  apparmor_dentry_open,
        .inode_getattr =                apparmor_inode_getattr,
 
+       .file_open =                    apparmor_file_open,
        .file_permission =              apparmor_file_permission,
        .file_alloc_security =          apparmor_file_alloc_security,
        .file_free_security =           apparmor_file_free_security,
index bbb5115..a1abbe0 100644 (file)
@@ -349,7 +349,7 @@ static int cap_file_receive(struct file *file)
        return 0;
 }
 
-static int cap_dentry_open(struct file *file, const struct cred *cred)
+static int cap_file_open(struct file *file, const struct cred *cred)
 {
        return 0;
 }
@@ -953,7 +953,7 @@ void __init security_fixup_ops(struct security_operations *ops)
        set_to_cap_if_null(ops, file_set_fowner);
        set_to_cap_if_null(ops, file_send_sigiotask);
        set_to_cap_if_null(ops, file_receive);
-       set_to_cap_if_null(ops, dentry_open);
+       set_to_cap_if_null(ops, file_open);
        set_to_cap_if_null(ops, task_create);
        set_to_cap_if_null(ops, cred_alloc_blank);
        set_to_cap_if_null(ops, cred_free);
index 4ba6d4c..56cdf7d 100644 (file)
@@ -686,11 +686,11 @@ int security_file_receive(struct file *file)
        return security_ops->file_receive(file);
 }
 
-int security_dentry_open(struct file *file, const struct cred *cred)
+int security_file_open(struct file *file, const struct cred *cred)
 {
        int ret;
 
-       ret = security_ops->dentry_open(file, cred);
+       ret = security_ops->file_open(file, cred);
        if (ret)
                return ret;
 
index 20219ef..9824815 100644 (file)
@@ -2948,7 +2948,7 @@ static int selinux_file_permission(struct file *file, int mask)
 
        if (sid == fsec->sid && fsec->isid == isec->sid &&
            fsec->pseqno == avc_policy_seqno())
/* No change since dentry_open check. */
                return 0;
 
        return selinux_revalidate_file_permission(file, mask);
@@ -3207,7 +3207,7 @@ static int selinux_file_receive(struct file *file)
        return file_has_perm(cred, file, file_to_av(file));
 }
 
-static int selinux_dentry_open(struct file *file, const struct cred *cred)
+static int selinux_file_open(struct file *file, const struct cred *cred)
 {
        struct file_security_struct *fsec;
        struct inode *inode;
@@ -5527,7 +5527,7 @@ static struct security_operations selinux_ops = {
        .file_send_sigiotask =          selinux_file_send_sigiotask,
        .file_receive =                 selinux_file_receive,
 
-       .dentry_open =                  selinux_dentry_open,
+       .file_open =                    selinux_file_open,
 
        .task_create =                  selinux_task_create,
        .cred_alloc_blank =             selinux_cred_alloc_blank,
index f997fc1..50b8587 100644 (file)
@@ -1357,7 +1357,7 @@ static int smack_file_receive(struct file *file)
 }
 
 /**
* smack_dentry_open - Smack dentry open processing
  * @file: the object
  * @cred: unused
  *
@@ -1365,7 +1365,7 @@ static int smack_file_receive(struct file *file)
  *
  * Returns 0
  */
-static int smack_dentry_open(struct file *file, const struct cred *cred)
+static int smack_file_open(struct file *file, const struct cred *cred)
 {
        struct inode_smack *isp = file->f_path.dentry->d_inode->i_security;
 
@@ -3469,7 +3469,7 @@ struct security_operations smack_ops = {
        .file_send_sigiotask =          smack_file_send_sigiotask,
        .file_receive =                 smack_file_receive,
 
-       .dentry_open =                  smack_dentry_open,
+       .file_open =                    smack_file_open,
 
        .cred_alloc_blank =             smack_cred_alloc_blank,
        .cred_free =                    smack_cred_free,
index 95d3f95..406315b 100644 (file)
@@ -181,7 +181,15 @@ static int tomoyo_file_fcntl(struct file *file, unsigned int cmd,
        return 0;
 }
 
-static int tomoyo_dentry_open(struct file *f, const struct cred *cred)
+/**
+ * tomoyo_file_open - Target for security_file_open().
+ *
+ * @f:    Pointer to "struct file".
+ * @cred: Pointer to "struct cred".
+ *
+ * Returns 0 on success, negative value otherwise.
+ */
+static int tomoyo_file_open(struct file *f, const struct cred *cred)
 {
        int flags = f->f_flags;
        /* Don't check read permission here if called from do_execve(). */
@@ -249,7 +257,7 @@ static struct security_operations tomoyo_security_ops = {
        .bprm_set_creds      = tomoyo_bprm_set_creds,
        .bprm_check_security = tomoyo_bprm_check_security,
        .file_fcntl          = tomoyo_file_fcntl,
-       .dentry_open         = tomoyo_dentry_open,
+       .file_open           = tomoyo_file_open,
        .path_truncate       = tomoyo_path_truncate,
        .path_unlink         = tomoyo_path_unlink,
        .path_mkdir          = tomoyo_path_mkdir,
@@ -2948,7 +2948,7 @@ static int selinux_file_permission(struct file *file, int mask)
        if (sid == fsec->sid && fsec->isid == isec->sid &&
            fsec->pseqno == avc_policy_seqno())
-               /* No change since dentry_open check. */
+               /* No change since file_open check. */
                return 0;
 
@@ -1357,7 +1357,7 @@ static int smack_file_receive(struct file *file)
 
 /**
- * smack_dentry_open - Smack dentry open processing
+ * smack_file_open - Smack dentry open processing
  * @file: the object
  * @cred: unused